==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Web_Links/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","Internetadresse");
define("_PREVIOUS","Forrige side");
define("_NEXT","Nste side");
define("_YOURNAME","Dit navn");
define("_CATEGORY","Kategori");
define("_CATEGORIES","Kategorier");
define("_LVOTES","stemmer");
define("_TOTALVOTES","Antal stemmer:");
define("_LINKTITLE","Titel p link");
define("_HITS","Hits");
define("_THEREARE","Der er");
define("_NOMATCHES","Sgningen gave ingen resultater");
define("_SCOMMENTS","Kommentarer");
define("_DESCRIPTION","Beskrivelse");
define("_ONLYREGUSERSMODIFY","Kun oprettede brugere kan foresl ndringer til downloads. Vr venlig at logge ind eller bliv oprettet som bruger.<a href=\"modules.php?name=Your_Account\">Log ind eller bliv bruger</a>.");
define("_DATE","Dato");
define("_TO","Til");
define("_ADDLINK","Foresl nyt link");
define("_NEW","Nye");
define("_POPULAR","Populre");
define("_TOPRATED","Bedste");
define("_RANDOM","Prv lykken");
define("_LINKSMAIN","Oversigt over links");
define("_LINKCOMMENTS","Linkkommentarer");
define("_ADDITIONALDET","Yderligere oplysninger");
define("_EDITORREVIEW","Anmeldelse");
define("_REPORTBROKEN","Anmeld et delagt link");
define("_LINKSMAINCAT","Links hovedkategorier");
define("_AND","og");
define("_INDB","i vores database");
define("_ADDALINK","Foresl nyt link");
define("_INSTRUCTIONS","Vejledning");
define("_SUBMITONCE","Indsend kun et link en gang.");
define("_POSTPENDING","Alle links bliver kontrolleret fr de bliver publiceret.");
define("_USERANDIP","Brugernavn og IP-adresse bliver registreret, s vr venlig ikke at misbruge systemet.");
define("_PAGETITLE","Navn");
define("_PAGEURL","Internetadresse");
define("_YOUREMAIL","Din e-mailadresse");
define("_LDESCRIPTION","Beskrivelse: (maks 255 tegn)");
define("_ADDURL","Send");
define("_LINKSNOTUSER1","Du er ikke oprettet som bruger eller ogs er du ikke logget ind.");
define("_LINKSNOTUSER2","Hvis du var oprettet som bruger kunne du oprette links og downloads her p websitet.");
define("_LINKSNOTUSER3","At blive oprettet som bruger er hurtigt og nemt.");
define("_LINKSNOTUSER4","Hvorfor krver vi registrering for at opn adgang til dele af vores site?");
define("_LINKSNOTUSER5","Fordi vi s kan tilbyde dig det bedst mulige kvalitetsindhold,");
define("_LINKSNOTUSER6","alt indhold bliver individuelt gennemget og godkendt af vores team.");
define("_LINKSNOTUSER7","Vi nsker udelukkende at kunne tilbyde dig kvalitetsindhold.");
define("_LINKSNOTUSER8","<a href=\"modules.php?name=Your_Account\">Opret dig som bruger</a>");
define("_LINKALREADYEXT","FEJL: Denne internetadresse er allerede listet i vores database!");
define("_LINKNOTITLE","FEJL: Du skal angive en titel til internetadressen!");
define("_LINKNOURL","FEJL: Du skal angive en titel til internetadressen!");
define("_LINKNODESC","FEJL: Du skal skrve en beskrivelse for internetadressen!");
define("_LINKRECEIVED","Vi har modtaget dit forslag til link. Tak!");
define("_EMAILWHENADD","Du vil modtage en e-mail nr det er godkendt.");
define("_CHECKFORIT","Du skrev ikke en e-mailadresse. Vi vil alligevel gennemse dit forslag snarest.");
define("_NEWLINKS","Nye links");
define("_TOTALNEWLINKS","Antal nye links");
define("_LASTWEEK","Sidste uge");
define("_LAST30DAYS","Sidste 30 dage");
define("_1WEEK","1 uge");
define("_2WEEKS","2 uger");
define("_30DAYS","30 dage");
define("_SHOW","Vis");
define("_TOTALFORLAST","Antal nye links de(n) sidste");
define("_DAYS","dage");
define("_ADDEDON","Oprettet");
define("_RATING","Rating");
define("_RATESITE","Rate dette website");
define("_DETAILS","Yderligere oplysninger");
define("_BESTRATED","Bedst ratede links");
define("_OF","af");
define("_TRATEDLINKS","antal ratede links");
define("_TVOTESREQ","stemmer er pkrvet som minimum");
define("_SHOWTOP","Vis bedste");
define("_MOSTPOPULAR","Mest populre - Top");
define("_OFALL","af alle");
define("_SORTLINKSBY","Sorter links efter");
define("_SITESSORTED","Websites sorteret efter");
define("_POPULARITY","Popularitet");
define("_SELECTPAGE","Vlg side");
define("_MAIN","Hovedkategori");
define("_NEWTODAY","Nye i dag");
define("_NEWLAST3DAYS","Nye de sidste tre dage");
define("_NEWTHISWEEK","Nye denne uge");
define("_CATNEWTODAY","Nye links i denne kategori oprettet i dag");
define("_CATLAST3DAYS","Nye links i denne kategori oprettet indenfor de sidste tre dage");
define("_CATTHISWEEK","Nye links i denne kategori oprettet indenfor den sidste uge");
define("_POPULARITY1","Popularitet (Frrest til flest hits)");
define("_POPULARITY2","Popularitet (Flest til frrest hits)");
define("_TITLEAZ","Titel (A til )");
define("_TITLEZA","Titel ( til A)");
define("_DATE1","Dato (Gamle links frst)");
define("_DATE2","Dato (Nye links frst)");
define("_RATING1","Rating (Laveste score til hjeste score)");
define("_RATING2","Rating (Hjeste score til laveste score)");
define("_SEARCHRESULTS4","Sgeresultater for");
define("_USUBCATEGORIES","Underkategorier");
define("_LINKS","Links");
define("_TRY2SEARCH","Prv at sge");
define("_INOTHERSENGINES","i andre sgemaskiner");
define("_EDITORIAL","Redaktionel leder");
define("_LINKPROFILE","Linkprofil");
define("_EDITORIALBY","Anmeldelse af");
define("_NOEDITORIAL","Ingen anmeldelse er tilgngeligt for dette website.");
define("_VISITTHISSITE","Besg siden");
define("_RATETHISSITE","Rate denne side");
define("_ISTHISYOURSITE","Er dette dit website?");
define("_ALLOWTORATE","Tillad andre at rate den fra dit website!");
define("_LINKRATINGDET","Ratingoplysninger for link");
define("_OVERALLRATING","Samlet rating");
define("_TOTALOF","Antal af");
define("_USER","Bruger");
define("_USERAVGRATING","Brugernes gennemsnitlige rating");
define("_NUMRATINGS","# af ratings");
define("_EDITTHISLINK","Redigr dette link");
define("_REGISTEREDUSERS","Registerede brugere");
define("_NUMBEROFRATINGS","Antal ratings");
define("_NOREGUSERSVOTES","Ingen registrede brugerstemmer");
define("_BREAKDOWNBYVAL","Nedbryd ratings efter vrdi");
define("_LTOTALVOTES","Antal stemmer");
define("_LINKRATING","Linksrating");
define("_HIGHRATING","Hje ratings");
define("_LOWRATING","Lave ratings");
define("_NUMOFCOMMENTS","Antal kommentarer");
define("_WEIGHNOTE","* Note: Vi vgter registrede mod uregistrede brugeres ratings.");
define("_NOUNREGUSERSVOTES","Ingen uregistrede brugerstemmer.");
define("_WEIGHOUTNOTE","Note: Vi vgter registrede mod udefrakommende stemmeratings");
define("_NOOUTSIDEVOTES","Ingen udefrakommende stemmer");
define("_OUTSIDEVOTERS","Udefrakommende stemmer");
define("_UNREGISTEREDUSERS","Uregistrerede brugere");
define("_PROMOTEYOURSITE","Reklamr for dit website");
define("_PROMOTE01","Mske vil du vre interesseret i muligheden for at 'Rate et Website' p din eget site. Vi har flere muligheder til rdighed. De tillader, at du kan placere et billede (eller en ratingform) p dit website for at forge antallet af stemmer som dit website modtager. Vlg mellem de forskellige muligheder nedenfor:");
define("_TEXTLINK","Tekstlink");
define("_PROMOTE02","en mulighed er at linke via et simpelt tekstlink:");
define("_HTMLCODE1","HTML-koden du skal bruger er som flger:");
define("_THENUMBER","Nummeret");
define("_IDREFER","i HTML-kilden refererer til dit sites ID-nummer i $sitename-databasen. Vr sikker p, at nummeret er tilstede.");
define("_BUTTONLINK","Knaplink");
define("_PROMOTE03","Hvis du er p udkig efter noget mere end bare et simpelt tekstlink, kan du bruge et lille knaplink:");
define("_RATEIT","Rate dette site!");
define("_HTMLCODE2","Kildekoden for ovenstende knap er:");
define("_REMOTEFORM","Udefrakommende ratingform");
define("_PROMOTE04","Vi tillader ikke snyd og vi holder je med forsg herp. Hvis vi opdager snyd vil linket blive slettet fra databasen. Med det i baghovedet s ser den nuvrende den eksterne ratingform ud sledes:");
define("_VOTE4THISSITE","Stem p denne side!");
define("_LINKVOTE","Stem!");
define("_HTMLCODE3","Hvis du bruger denne ratingform kan dine brugere stemme p dit website i vores database direkte fra dit eget site. Ratingen vil blive gemt i vors database. Ovenstende form er deaktiveret, men den nedenstende kildekode virker hvis du laver kopir og st ind i din side. Husk, at tallet 14 angiver dit sites nummer i vores database. Kontrollr, at det passer!");
define("_PROMOTE05","Held og lykke med dine ratings!");
define("_STAFF","-Teamet");
define("_THANKSBROKEN","Tak for din hjlp!");
define("_THANKSFORINFO","Tak for oplysningerne.");
define("_LOOKTOREQUEST","Vi vil snarest gennemse din forslag.");
define("_REQUESTLINKMOD","Foreslag om ndring af link");
define("_LINKID","Link ID");
define("_SENDREQUEST","Send anmodning");
define("_THANKSTOTAKETIME","Tak fordi du tog dig tid til at rate et site her hos");
define("_LETSDECIDE","Tilbagemeldinger fra brugere som dig selv, er med til at hjlpe andre besgende med at vlge hvilke links, de skal klikke p.");
define("_RETURNTO","Tilbage til");
define("_RATENOTE1","Stem ikke p det samme mere end en gang.");
define("_RATENOTE2","Skalaen er 1 til 10, hvor 1 er det laveste og 10 det hjeste.");
define("_RATENOTE3","Vr s objektiv som muligt i din stemmeafgivelse, hvis alle modtager 1 eller 10, kan ratings ikke bruges til noget.");
define("_RATENOTE4","Du kan se en liste med de <a href=\"modules.php?name=Web_Links&amp;l_op=TopRated\">bedst ratede links</a>.");
define("_RATENOTE5","Stem ikke p din egen side eller p et konkurrerende site.");
define("_YOUAREREGGED","Du er oprettet som bruger og er logget ind.");
define("_FEELFREE2ADD","Skriv en kommentar om denne side hvis du har lyst.");
define("_YOUARENOTREGGED","Du er ikke oprettet som bruger eller ogs er du ikke logget ind.");
define("_IFYOUWEREREG","Hvis du var oprettet som bruger kunne du komme med kommentarer p dette website.");
define("_WEBLINKS","Administration af Links");
define("_TITLE","Titel");
define("_MODIFY","ndring");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Web_Links/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","Internetadresse");
define("_PREVIOUS","Forrige side");
define("_NEXT","Nste side");
define("_YOURNAME","Dit navn");
define("_CATEGORY","Kategori");
define("_CATEGORIES","Kategorier");
define("_LVOTES","stemmer");
define("_TOTALVOTES","Antal stemmer:");
define("_LINKTITLE","Titel p link");
define("_HITS","Hits");
define("_THEREARE","Der er");
define("_NOMATCHES","Sgningen gave ingen resultater");
define("_SCOMMENTS","Kommentarer");
define("_DESCRIPTION","Beskrivelse");
define("_ONLYREGUSERSMODIFY","Kun oprettede brugere kan foresl ndringer til downloads. Vr venlig at logge ind eller bliv oprettet som bruger.<a href=\"modules.php?name=Your_Account\">Log ind eller bliv bruger</a>.");
define("_DATE","Dato");
define("_TO","Til");
define("_ADDLINK","Foresl nyt link");
define("_NEW","Nye");
define("_POPULAR","Populre");
define("_TOPRATED","Bedste");
define("_RANDOM","Prv lykken");
define("_LINKSMAIN","Oversigt over links");
define("_LINKCOMMENTS","Linkkommentarer");
define("_ADDITIONALDET","Yderligere oplysninger");
define("_EDITORREVIEW","Anmeldelse");
define("_REPORTBROKEN","Anmeld et delagt link");
define("_LINKSMAINCAT","Links hovedkategorier");
define("_AND","og");
define("_INDB","i vores database");
define("_ADDALINK","Foresl nyt link");
define("_INSTRUCTIONS","Vejledning");
define("_SUBMITONCE","Indsend kun et link en gang.");
define("_POSTPENDING","Alle links bliver kontrolleret fr de bliver publiceret.");
define("_USERANDIP","Brugernavn og IP-adresse bliver registreret, s vr venlig ikke at misbruge systemet.");
define("_PAGETITLE","Navn");
define("_PAGEURL","Internetadresse");
define("_YOUREMAIL","Din e-mailadresse");
define("_LDESCRIPTION","Beskrivelse: (maks 255 tegn)");
define("_ADDURL","Send");
define("_LINKSNOTUSER1","Du er ikke oprettet som bruger eller ogs er du ikke logget ind.");
define("_LINKSNOTUSER2","Hvis du var oprettet som bruger kunne du oprette links og downloads her p websitet.");
define("_LINKSNOTUSER3","At blive oprettet som bruger er hurtigt og nemt.");
define("_LINKSNOTUSER4","Hvorfor krver vi registrering for at opn adgang til dele af vores site?");
define("_LINKSNOTUSER5","Fordi vi s kan tilbyde dig det bedst mulige kvalitetsindhold,");
define("_LINKSNOTUSER6","alt indhold bliver individuelt gennemget og godkendt af vores team.");
define("_LINKSNOTUSER7","Vi nsker udelukkende at kunne tilbyde dig kvalitetsindhold.");
define("_LINKSNOTUSER8","<a href=\"modules.php?name=Your_Account\">Opret dig som bruger</a>");
define("_LINKALREADYEXT","FEJL: Denne internetadresse er allerede listet i vores database!");
define("_LINKNOTITLE","FEJL: Du skal angive en titel til internetadressen!");
define("_LINKNOURL","FEJL: Du skal angive en titel til internetadressen!");
define("_LINKNODESC","FEJL: Du skal skrve en beskrivelse for internetadressen!");
define("_LINKRECEIVED","Vi har modtaget dit forslag til link. Tak!");
define("_EMAILWHENADD","Du vil modtage en e-mail nr det er godkendt.");
define("_CHECKFORIT","Du skrev ikke en e-mailadresse. Vi vil alligevel gennemse dit forslag snarest.");
define("_NEWLINKS","Nye links");
define("_TOTALNEWLINKS","Antal nye links");
define("_LASTWEEK","Sidste uge");
define("_LAST30DAYS","Sidste 30 dage");
define("_1WEEK","1 uge");
define("_2WEEKS","2 uger");
define("_30DAYS","30 dage");
define("_SHOW","Vis");
define("_TOTALFORLAST","Antal nye links de(n) sidste");
define("_DAYS","dage");
define("_ADDEDON","Oprettet");
define("_RATING","Rating");
define("_RATESITE","Rate dette website");
define("_DETAILS","Yderligere oplysninger");
define("_BESTRATED","Bedst ratede links");
define("_OF","af");
define("_TRATEDLINKS","antal ratede links");
define("_TVOTESREQ","stemmer er pkrvet som minimum");
define("_SHOWTOP","Vis bedste");
define("_MOSTPOPULAR","Mest populre - Top");
define("_OFALL","af alle");
define("_SORTLINKSBY","Sorter links efter");
define("_SITESSORTED","Websites sorteret efter");
define("_POPULARITY","Popularitet");
define("_SELECTPAGE","Vlg side");
define("_MAIN","Hovedkategori");
define("_NEWTODAY","Nye i dag");
define("_NEWLAST3DAYS","Nye de sidste tre dage");
define("_NEWTHISWEEK","Nye denne uge");
define("_CATNEWTODAY","Nye links i denne kategori oprettet i dag");
define("_CATLAST3DAYS","Nye links i denne kategori oprettet indenfor de sidste tre dage");
define("_CATTHISWEEK","Nye links i denne kategori oprettet indenfor den sidste uge");
define("_POPULARITY1","Popularitet (Frrest til flest hits)");
define("_POPULARITY2","Popularitet (Flest til frrest hits)");
define("_TITLEAZ","Titel (A til )");
define("_TITLEZA","Titel ( til A)");
define("_DATE1","Dato (Gamle links frst)");
define("_DATE2","Dato (Nye links frst)");
define("_RATING1","Rating (Laveste score til hjeste score)");
define("_RATING2","Rating (Hjeste score til laveste score)");
define("_SEARCHRESULTS4","Sgeresultater for");
define("_USUBCATEGORIES","Underkategorier");
define("_LINKS","Links");
define("_TRY2SEARCH","Prv at sge");
define("_INOTHERSENGINES","i andre sgemaskiner");
define("_EDITORIAL","Redaktionel leder");
define("_LINKPROFILE","Linkprofil");
define("_EDITORIALBY","Anmeldelse af");
define("_NOEDITORIAL","Ingen anmeldelse er tilgngeligt for dette website.");
define("_VISITTHISSITE","Besg siden");
define("_RATETHISSITE","Rate denne side");
define("_ISTHISYOURSITE","Er dette dit website?");
define("_ALLOWTORATE","Tillad andre at rate den fra dit website!");
define("_LINKRATINGDET","Ratingoplysninger for link");
define("_OVERALLRATING","Samlet rating");
define("_TOTALOF","Antal af");
define("_USER","Bruger");
define("_USERAVGRATING","Brugernes gennemsnitlige rating");
define("_NUMRATINGS","# af ratings");
define("_EDITTHISLINK","Redigr dette link");
define("_REGISTEREDUSERS","Registerede brugere");
define("_NUMBEROFRATINGS","Antal ratings");
define("_NOREGUSERSVOTES","Ingen registrede brugerstemmer");
define("_BREAKDOWNBYVAL","Nedbryd ratings efter vrdi");
define("_LTOTALVOTES","Antal stemmer");
define("_LINKRATING","Linksrating");
define("_HIGHRATING","Hje ratings");
define("_LOWRATING","Lave ratings");
define("_NUMOFCOMMENTS","Antal kommentarer");
define("_WEIGHNOTE","* Note: Vi vgter registrede mod uregistrede brugeres ratings.");
define("_NOUNREGUSERSVOTES","Ingen uregistrede brugerstemmer.");
define("_WEIGHOUTNOTE","Note: Vi vgter registrede mod udefrakommende stemmeratings");
define("_NOOUTSIDEVOTES","Ingen udefrakommende stemmer");
define("_OUTSIDEVOTERS","Udefrakommende stemmer");
define("_UNREGISTEREDUSERS","Uregistrerede brugere");
define("_PROMOTEYOURSITE","Reklamr for dit website");
define("_PROMOTE01","Mske vil du vre interesseret i muligheden for at 'Rate et Website' p din eget site. Vi har flere muligheder til rdighed. De tillader, at du kan placere et billede (eller en ratingform) p dit website for at forge antallet af stemmer som dit website modtager. Vlg mellem de forskellige muligheder nedenfor:");
define("_TEXTLINK","Tekstlink");
define("_PROMOTE02","en mulighed er at linke via et simpelt tekstlink:");
define("_HTMLCODE1","HTML-koden du skal bruger er som flger:");
define("_THENUMBER","Nummeret");
define("_IDREFER","i HTML-kilden refererer til dit sites ID-nummer i $sitename-databasen. Vr sikker p, at nummeret er tilstede.");
define("_BUTTONLINK","Knaplink");
define("_PROMOTE03","Hvis du er p udkig efter noget mere end bare et simpelt tekstlink, kan du bruge et lille knaplink:");
define("_RATEIT","Rate dette site!");
define("_HTMLCODE2","Kildekoden for ovenstende knap er:");
define("_REMOTEFORM","Udefrakommende ratingform");
define("_PROMOTE04","Vi tillader ikke snyd og vi holder je med forsg herp. Hvis vi opdager snyd vil linket blive slettet fra databasen. Med det i baghovedet s ser den nuvrende den eksterne ratingform ud sledes:");
define("_VOTE4THISSITE","Stem p denne side!");
define("_LINKVOTE","Stem!");
define("_HTMLCODE3","Hvis du bruger denne ratingform kan dine brugere stemme p dit website i vores database direkte fra dit eget site. Ratingen vil blive gemt i vors database. Ovenstende form er deaktiveret, men den nedenstende kildekode virker hvis du laver kopir og st ind i din side. Husk, at tallet 14 angiver dit sites nummer i vores database. Kontrollr, at det passer!");
define("_PROMOTE05","Held og lykke med dine ratings!");
define("_STAFF","-Teamet");
define("_THANKSBROKEN","Tak for din hjlp!");
define("_THANKSFORINFO","Tak for oplysningerne.");
define("_LOOKTOREQUEST","Vi vil snarest gennemse din forslag.");
define("_REQUESTLINKMOD","Foreslag om ndring af link");
define("_LINKID","Link ID");
define("_SENDREQUEST","Send anmodning");
define("_THANKSTOTAKETIME","Tak fordi du tog dig tid til at rate et site her hos");
define("_LETSDECIDE","Tilbagemeldinger fra brugere som dig selv, er med til at hjlpe andre besgende med at vlge hvilke links, de skal klikke p.");
define("_RETURNTO","Tilbage til");
define("_RATENOTE1","Stem ikke p det samme mere end en gang.");
define("_RATENOTE2","Skalaen er 1 til 10, hvor 1 er det laveste og 10 det hjeste.");
define("_RATENOTE3","Vr s objektiv som muligt i din stemmeafgivelse, hvis alle modtager 1 eller 10, kan ratings ikke bruges til noget.");
define("_RATENOTE4","Du kan se en liste med de <a href=\"modules.php?name=Web_Links&amp;l_op=TopRated\">bedst ratede links</a>.");
define("_RATENOTE5","Stem ikke p din egen side eller p et konkurrerende site.");
define("_YOUAREREGGED","Du er oprettet som bruger og er logget ind.");
define("_FEELFREE2ADD","Skriv en kommentar om denne side hvis du har lyst.");
define("_YOUARENOTREGGED","Du er ikke oprettet som bruger eller ogs er du ikke logget ind.");
define("_IFYOUWEREREG","Hvis du var oprettet som bruger kunne du komme med kommentarer p dette website.");
define("_WEBLINKS","Administration af Links");
define("_TITLE","Titel");
define("_MODIFY","ndring");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>
